ORQUESTRA_HOME_FUNCTION 	= None

ORQUESTRA_HOME 		   = 0
ORQUESTRA_NEW_TAB 	   = 1
ORQUESTRA_NEW_WINDOW   = 2
ORQUESTRA_APPEND_HOME  = 3
ORQUESTRA_HOME_FULL    = 4
ORQUESTRA_NEW_TAB_FULL = 5
ORQUESTRA_NEW_BIGWINDOW = 6

ORQUESTRA_EXTRA_CSS_FILE = None

ORQUESTRA_REQUIREAUTH = False

ORQUESTRA_SHOW_NO_MODULE_EXCEPTION = False

ORQUESTRA_TITLE = ''
ORQUESTRA_PAGE_TITLE = ''

ORQUESTRA_GOOGLE_ANALYTICS = None